#
# Rules.make - make rules for ztp-zbierka
#              This file is included by 'make' from Makefile
#
# Developed by Lubomir Host 'rajo' <rajo AT platon.sk>
# Copyright (c) 2003 Platon SDG
# Licensed under terms of GNU General Public License.
# All rights reserved.
#
# $Platon$
#

export DATA_DIR
export GRAPHS_DIR
export IMAGES_DIR
export DEPEND
DEPEND_all  = $(DEPEND) $(IMAGES) $(DATA) $(GRAPHS)

OUTPUT            = $(ps__OUTPUT) $(pdf_OUTPUT)
export OUTPUT
export ps__OUTPUT
export pdf_OUTPUT

ps__INPUT    = $(patsubst %.ps,%.tex,$(ps__OUTPUT))
pdf_INPUT    = $(patsubst %.pdf,%.tex,$(pdf_OUTPUT))
export ps__INPUT
export pdf_INPUT

DVI_ps__OUTPUT    = $(patsubst %.ps,%.dvi,$(ps__OUTPUT))
DVI_pdf_OUTPUT    = $(patsubst %.pdf,%.dvi,$(pdf_OUTPUT))
DVI_OUTPUT        = $(DVI_ps__OUTPUT) $(DVI_pdf_OUTPUT)

ps__OUTPUT_first  = $(patsubst %,.first.%,$(ps__OUTPUT))
pdf_OUTPUT_first  = $(patsubst %,.first.%,$(pdf_OUTPUT))
OUTPUT_first      = $(ps__OUTPUT_first)

ps__OUTPUT_second = $(patsubst %,.second.%,$(ps__OUTPUT))
pdf_OUTPUT_second = $(patsubst %,.second.%,$(pdf_OUTPUT))
OUTPUT_second     = $(ps__OUTPUT_second)

ps__OUTPUT_third  = $(patsubst %,.third.%,$(ps__OUTPUT))
pdf_OUTPUT_third  = $(patsubst %,.third.%,$(pdf_OUTPUT))
OUTPUT_third      = $(ps__OUTPUT_third)

.SUFFIXES:

all: ps-subdir pdf-subdir

ps-subdir:
	-@./build-struct "PostScript" \
		&& $(MAKE) -C PostScript PostScript

pdf-subdir:
	-@./build-struct "PDF" \
		&& $(MAKE) -C PDF PDF

PostScript: $(ps__OUTPUT_first) $(ps__OUTPUT_second) $(ps__OUTPUT_third) $(DVI_ps__OUTPUT) $(ps__OUTPUT)

PDF: $(pdf_OUTPUT)

%.ps: %.dvi $(ps__OUTPUT_first) $(ps__OUTPUT_second) $(ps__OUTPUT_third)
	$(DVIPS) -o $@ $<

%.pdf: $(pdf_OUTPUT_first) $(DEPEND_all)
	@file="`echo '$@'`"; \
	echo "$(PDFLATEX) $${file%.pdf}.tex"; \
	$(PDFLATEX) $${file%.pdf}.tex \

%.dvi: .third.%.ps

.third.%.ps: %.tex $(DEPEND_all) .second.%.ps
	$(LATEX) $< \
		&& touch $@

.second.%.ps: .first.%.ps
	@file="`echo '$@' | sed 's/^.second.//g;'`"; \
	echo "$(LATEX_BATCH) $${file%.ps}.tex"; \
	$(LATEX_BATCH) $${file%.ps}.tex \
		&& touch $@
	
.first.%.pdf: %.tex
	$(PDFLATEX_BATCH) $< \
		&& touch $@

.first.%.ps:
	@file="`echo '$@' | sed 's/^.first.//g;'`"; \
	echo "$(LATEX_BATCH) $${file%.ps}.tex"; \
	$(LATEX_BATCH) $${file%.ps}.tex \
		&& touch $@ || (cat $${file%.ps}.log; exit 1 )

view: 
	for i in $(OUTPUT); do \
		test -f "$$i" && $(GV) $$i & \
	done

# Vytvaranie grafov programom gnuplot
%.eps: %.gp $(DATA)
	$(GNUPLOT) $<

# Empty - nothing to be done for install ;)
install:
	
# Clean {{{
# zmazanie docasnych suborov
clean: clean-tex-logs clean-graphs clean-postscript clean-pdf
	-rm -f .first.* .second.* .third.* core core.*

clean-postscript:
	-rm -rf PostScript/

clean-pdf:
	-rm -rf PDF/

# zmazanie docasnych suborov vytvorenych programom latex
clean-tex-logs:
	@for OUT in $(OUTPUT); \
	do \
		file="$${OUT%.ps}"; \
		file_list=""; \
		for i in $${file%.pdf}{.aux,.brf,.log,.lof,.lot,.out,.toc,.dvi,.ps,.pdf} ; \
		do \
			file_list="$$file_list $$i"; \
		done; \
	done; \
	filelist="`echo $$file_list | awk -v RS=' ' '{print}' | sort -u | awk -v ORS=' ' '{print}'`"; \
	echo -en "[36mDeleting extensions `echo $$asdf{.aux,.brf,.log,.lof,.lot,.out,.toc,.dvi,.ps,.pdf} `[0m"; echo; \
	echo "rm -f $$filelist"; \
	rm -f $$filelist; \

# zmazanie vytvorenych grafov
clean-graphs:
	@test -z "$(GRAPHS)" || \
	for i in "$(GRAPHS)" ; \
	do \
		echo "rm -f $$i"; rm -f $$i; \
	done \
# }}}

# Distribution {{{
dist: distdir
	GZIP=$(GZIP_ENV) $(TAR) chozf $(distdir).tar.gz  $(distdir)
	@#BZIP=$(GZIP_ENV) $(TAR) chojf $(distdir).tar.bz2 $(distdir)
	-rm -rf $(distdir)
	@#-@banner="md5sum is: `md5sum $(distdir).tar.gz |tee md5sum.$(distdir)`"; \
	dashes=`echo "$$banner" | sed s/./=/g`; \
	echo "$$dashes"; \
	echo "$$banner"; \
	echo "$$dashes"

distdir: $(DISTFILES)
	-rm -rf $(distdir)
	mkdir $(distdir)
	-chmod a+rx $(distdir)
	@here=`cd $(top_builddir) && pwd`; \
	top_distdir=`cd $(distdir) && pwd`; \
	distdir=`cd $(distdir) && pwd`; \
	umask 022; \
	for file in $(DISTFILES); do \
	  d=$(srcdir); \
	  if test -d $$d/$$file; then \
	    mkdir $(distdir)/$$file; \
	  else \
	    test -f $(distdir)/$$file \
	    || cp $$d/$$file $(distdir)/$$file || :; \
	  fi; \
	done

# }}}

# vim: ts=4 isk+=- ft=make
# vim600: fdm=marker fdc=3

